@@ -1,59 +1,64 @@
 #source: https://github.com/Opticos/GWSL-Source/blob/master/blur.py , https://www.cnblogs.com/zhiyiYo/p/14659981.html , https://github.com/ifwe/digsby/blob/master/digsby/src/gui/vista.py
-
-from ctypes.wintypes import  DWORD, BOOL, HRGN
+import platform
 import ctypes
 
-user32 = ctypes.windll.user32
-dwm = ctypes.windll.dwmapi
-
-class ACCENTPOLICY(ctypes.Structure):
-    _fields_ = [
-        ("AccentState", ctypes.c_uint),
-        ("AccentFlags", ctypes.c_uint),
-        ("GradientColor", ctypes.c_uint),
-        ("AnimationId", ctypes.c_uint)
-    ]
+if platform.system() == 'Windows':
+    from ctypes.wintypes import  DWORD, BOOL, HRGN
+    user32 = ctypes.windll.user32
+    dwm = ctypes.windll.dwmapi
 
 
-class WINDOWCOMPOSITIONATTRIBDATA(ctypes.Structure):
-    _fields_ = [
-        ("Attribute", ctypes.c_int),
-        ("Data", ctypes.POINTER(ctypes.c_int)),
-        ("SizeOfData", ctypes.c_size_t)
-    ]
+    class ACCENTPOLICY(ctypes.Structure):
+        _fields_ = [
+            ("AccentState", ctypes.c_uint),
+            ("AccentFlags", ctypes.c_uint),
+            ("GradientColor", ctypes.c_uint),
+            ("AnimationId", ctypes.c_uint)
+        ]
 
 
-class DWM_BLURBEHIND(ctypes.Structure):
-    _fields_ = [
-        ('dwFlags', DWORD), 
-        ('fEnable', BOOL),  
-        ('hRgnBlur', HRGN), 
-        ('fTransitionOnMaximized', BOOL) 
-    ]
+    class WINDOWCOMPOSITIONATTRIBDATA(ctypes.Structure):
+        _fields_ = [
+            ("Attribute", ctypes.c_int),
+            ("Data", ctypes.POINTER(ctypes.c_int)),
+            ("SizeOfData", ctypes.c_size_t)
+        ]
 
 
-class MARGINS(ctypes.Structure):
-    _fields_ = [("cxLeftWidth", ctypes.c_int),
-                ("cxRightWidth", ctypes.c_int),
-                ("cyTopHeight", ctypes.c_int),
-                ("cyBottomHeight", ctypes.c_int)
-                ]
+    class DWM_BLURBEHIND(ctypes.Structure):
+        _fields_ = [
+            ('dwFlags', DWORD), 
+            ('fEnable', BOOL),  
+            ('hRgnBlur', HRGN), 
+            ('fTransitionOnMaximized', BOOL) 
+        ]
 
 
-def Win7Blur(HWND):
-    DWM_BB_ENABLE = 0x01
-    bb = DWM_BLURBEHIND()
-    bb.dwFlags = DWM_BB_ENABLE
-    bb.fEnable = 1
-    bb.hRgnBlur = 1
-    dwm.DwmEnableBlurBehindWindow(HWND, ctypes.byref(bb))
+    class MARGINS(ctypes.Structure):
+        _fields_ = [("cxLeftWidth", ctypes.c_int),
+                    ("cxRightWidth", ctypes.c_int),
+                    ("cyTopHeight", ctypes.c_int),
+                    ("cyBottomHeight", ctypes.c_int)
+                    ]
 
 
 def ExtendFrameIntoClientArea(HWND):
-    margins = MARGINS(0, 0, 0, 0)
+    margins = MARGINS(-1, -1, -1, -1)
     dwm.DwmExtendFrameIntoClientArea(HWND, ctypes.byref(margins))
 
 
+def Win7Blur(HWND,Acrylic):
+    if Acrylic == False:
+        DWM_BB_ENABLE = 0x01
+        bb = DWM_BLURBEHIND()
+        bb.dwFlags = DWM_BB_ENABLE
+        bb.fEnable = 1
+        bb.hRgnBlur = 1
+        dwm.DwmEnableBlurBehindWindow(HWND, ctypes.byref(bb))
+    else:
+        ExtendFrameIntoClientArea(HWND)
+
+
 def HEXtoRGBAint(HEX:str):
     alpha = HEX[7:]
     blue = HEX[5:7]
@@ -77,6 +82,7 @@ def blur(HWND,hexColor=False,Acrylic=False,Dark=False):
     if Acrylic:
         accent.AccentState = 4 #UWP but LAG #ACCENT_ENABLE_ACRYLICBLURBEHIND
         if hexColor == False: #UWP without color is translucent
+            accent.AccentFlags = 2
             gradientColor = HEXtoRGBAint('#12121240') #placeholder color
     
     accent.GradientColor = gradientColor
@@ -92,18 +98,29 @@ def blur(HWND,hexColor=False,Acrylic=False,Dark=False):
         data.Attribute = 26 #WCA_USEDARKMODECOLORS
         user32.SetWindowCompositionAttribute(HWND, data)
 
+def BlurLinux(WID): #may not work in all distros (working in Deepin)
+    import os
+
+    c = "xprop -f _KDE_NET_WM_BLUR_BEHIND_REGION 32c -set _KDE_NET_WM_BLUR_BEHIND_REGION 0 -id " + str(WID)
+    os.system(c)
+
+
 def GlobalBlur(HWND,hexColor=False,Acrylic=False,Dark=False):
-    import platform
     release = platform.release()
-    
-    if release == 'Vista': 
-        Win7Blur(HWND)
-    else:
-        release = int(float(release))
-        if release == 10 or release == 8 or release == 11: #idk what windows 8.1 spits, if is '8.1' int(float(release)) will work...
-            blur(HWND,hexColor,Acrylic,Dark)
+    system = platform.system()
+
+    if system == 'Windows':
+        if release == 'Vista': 
+            Win7Blur(HWND,Acrylic)
         else:
-            Win7Blur(HWND)
+            release = int(float(release))
+            if release == 10 or release == 8 or release == 11: #idk what windows 8.1 spits, if is '8.1' int(float(release)) will work...
+                blur(HWND,hexColor,Acrylic,Dark)
+            else:
+                Win7Blur(HWND,Acrylic)
+    
+    if system == 'Linux':
+        BlurLinux(HWND)
 
 if __name__ == '__main__':
     import sys
@@ -131,4 +148,3 @@ if __name__ == '__main__':
     #ExtendFrameIntoClientArea(mw.winId())
 
     sys.exit(app.exec_())
-
